package provider

import (
	"github.com/hashicorp/terraform-plugin-framework/datasource"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/account"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/bservice"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/disks"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/extnet"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/flipgroup"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/image"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/k8s"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/kvmvm"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/lb"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/rg"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/stack"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/vfpool"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/vins"
	cbaccount "repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudbroker/account"
	cbStack "repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudbroker/stack"
)

func newDataSourcesMap() []func() datasource.DataSource {
	return []func() datasource.DataSource{
		account.NewDataSourceAccount,
		account.NewDataSourceAccountAuditsList,
		account.NewDataSourceAccountComputesList,
		account.NewDataSourceAccountConsumedUnits,
		account.NewDataSourceAccountConsumedUnitsByType,
		account.NewDataSourceAccountDisksList,
		account.NewDataSourceAccountFlipgroupsList,
		account.NewDataSourceAccountList,
		account.NewDataSourceAccountListDeleted,
		account.NewDataSourceAccountRGList,
		account.NewDataSourceAccountTemplatesList,
		account.NewDataSourceAccountVinsList,
		account.NewDataSourceAccountGetResourceConsumption,
		account.NewDataSourceAccountReservedUnits,
		account.NewDataSourceAccountGetResourceConsumptionList,

		bservice.NewDataSourceBService,
		bservice.NewDataSourceBServiceList,
		bservice.NewDataSourceBServiceGroup,
		bservice.NewDataSourceBServiceDeletedList,
		bservice.NewDataSourceBServiceSnapshotList,

		disks.NewDataSourceDisk,
		disks.NewDataSourceDiskList,
		disks.NewDataSourceDiskListDeleted,
		disks.NewDataSourceDiskListTypes,
		disks.NewDataSourceDiskListTypesDetailed,
		disks.NewDataSourceDiskListUnattached,
		disks.NewDataSourceDiskSnapshot,
		disks.NewDataSourceDiskSnapshotList,
		disks.NewDataSourceDiskReplication,

		extnet.NewDataSourceExtNet,
		extnet.NewDataSourceExtNetComputesList,
		extnet.NewDataSourceExtNetDefault,
		extnet.NewDataSourceExtNetList,

		flipgroup.NewDataSourceFlipgroup,
		flipgroup.NewDataSourceFlipgroupList,

		image.NewDataSourceImage,
		image.NewDataSourceImageList,

		k8s.NewDataSourceK8S,
		k8s.NewDataSourceK8SWgCloudInit,
		k8s.NewDataSourceK8SList,
		k8s.NewDataSourceK8SListDeleted,
		k8s.NewDataSourceK8SWg,
		k8s.NewDataSourceK8SComputes,
		k8s.NewDataSourceK8ciList,
		k8s.NewDataSourceK8SWgList,

		kvmvm.NewDataSourceComputeAudits,
		kvmvm.NewDataSourceComputeGetAudits,
		kvmvm.NewDataSourceComputeGetConsoleUrl,
		kvmvm.NewDataSourceComputeGetLog,
		kvmvm.NewDataSourceComputePciDeviceList,
		kvmvm.NewDataSourceComputePFWList,
		kvmvm.NewDataSourceComputeSnapshotUsage,
		kvmvm.NewDataSourceComputeUserList,
		kvmvm.NewDataSourceComputeVGPUList,
		kvmvm.NewDataSourceComputeList,
		kvmvm.NewDataSourceComputeListDeleted,
		kvmvm.NewDataSourceCompute,

		lb.NewDataSourceLB,
		lb.NewDataSourceLBList,
		lb.NewDataSourceLBListDeleted,

		rg.NewDataSourceRG,
		rg.NewDataSourceRGAffinityGroupComputes,
		rg.NewDataSourceRGAffinityGroupsGet,
		rg.NewDataSourceRGAffinityGroupsList,
		rg.NewDataSourceRGAudits,
		rg.NewDataSourceRGGetResourceConsumption,
		rg.NewDataSourceRGList,
		rg.NewDataSourceRGListComputes,
		rg.NewDataSourceRGListDeleted,
		rg.NewDataSourceRGListLB,
		rg.NewDataSourceRGListPFW,
		rg.NewDataSourceRGListVins,
		rg.NewDataSourceRGResourceConsumptionList,
		rg.NewDataSourceRGUsage,

		stack.NewDataSourceStack,
		stack.NewDataSourceStackList,

		vfpool.NewDataSourceVFPool,
		vfpool.NewDataSourceVFPoolList,

		vins.NewDataSourceVINS,
		vins.NewDataSourceVINSAudits,
		vins.NewDataSourceVINSExtNetList,
		vins.NewDataSourceVINSIPList,
		vins.NewDataSourceVINSList,
		vins.NewDataSourceVINSListDeleted,
		vins.NewDataSourceVINSNATRuleList,
		vins.NewDataSourceVINSStaticRoute,
		vins.NewDataSourceVINSStaticRouteList,

		cbaccount.NewDataSourceAccount,
		cbaccount.NewDataSourceAccountList,
		cbaccount.NewDataSourceAccountVinsList,

		cbStack.NewDataSourceStack,
		cbStack.NewDataSourceStackList,
	}
}
