package utilities

import (
	"context"
	"fmt"

	"github.com/hashicorp/terraform-plugin-framework/diag"
	"github.com/hashicorp/terraform-plugin-log/tflog"
	decort "repository.basistech.ru/BASIS/decort-golang-sdk"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudapi/lb"
)

func LBDataSourceCheckPresence(ctx context.Context, lbId uint64, c *decort.DecortClient) (*lb.RecordLB, diag.Diagnostics) {
	tflog.Info(ctx, fmt.Sprintf("LBDataSourceCheckPresence: Get info about lb with ID - %v", lbId))

	diags := diag.Diagnostics{}

	recordLB, err := c.CloudAPI().LB().Get(ctx, lb.GetRequest{LBID: lbId})
	if err != nil {
		diags.AddError(fmt.Sprintf("Cannot get info about lb with ID %v", lbId), err.Error())
		return nil, diags
	}

	tflog.Info(ctx, "LBDataSourceCheckPresence: response from CloudAPI().LB().Get", map[string]any{"lb_id": lbId, "response": recordLB})

	return recordLB, nil
}
