package rg

import (
	"context"

	"github.com/hashicorp/terraform-plugin-framework-timeouts/datasource/timeouts"
	"github.com/hashicorp/terraform-plugin-framework/datasource"
	"github.com/hashicorp/terraform-plugin-framework/datasource/schema"
	"github.com/hashicorp/terraform-plugin-log/tflog"
	decort "repository.basistech.ru/BASIS/decort-golang-sdk"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/client"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/constants"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/rg/flattens"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/rg/models"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/rg/schemas"
)

// Ensure the implementation satisfies the expected interfaces.
var (
	_ datasource.DataSource = &dataSourceRGAffinityGroupsGet{}
)

func NewDataSourceRGAffinityGroupsGet() datasource.DataSource {
	return &dataSourceRGAffinityGroupsGet{}
}

// dataSourceRGAffinityGroupsGet is the data source implementation.
type dataSourceRGAffinityGroupsGet struct {
	client *decort.DecortClient
}

func (d *dataSourceRGAffinityGroupsGet) Read(ctx context.Context, req datasource.ReadRequest, resp *datasource.ReadResponse) {
	// Read Terraform configuration data into the model
	var state models.DataSourceRGAffinityGroupsGetModel
	resp.Diagnostics.Append(req.Config.Get(ctx, &state)...)
	if resp.Diagnostics.HasError() {
		tflog.Error(ctx, "Read dataSourceRGAffinityGroupsGet: Error get state")
		return
	}
	tflog.Info(ctx, "Read dataSourceRGAffinityGroupsGet: got state successfully")

	// Set timeouts
	readTimeout, diags := state.Timeouts.Read(ctx, constants.Timeout30s)
	resp.Diagnostics.Append(diags...)
	if resp.Diagnostics.HasError() {
		tflog.Error(ctx, "Read dataSourceRGAffinityGroupsGet: Error set timeout")
		return
	}
	tflog.Info(ctx, "Read dataSourceRGAffinityGroupsGet: set timeouts successfully", map[string]any{
		"readTimeout": readTimeout})

	ctx, cancel := context.WithTimeout(ctx, readTimeout)
	defer cancel()

	// Map response body to schema
	resp.Diagnostics.Append(flattens.RGAffinityGroupsGetDataSource(ctx, &state, d.client)...)
	if resp.Diagnostics.HasError() {
		tflog.Error(ctx, "Read dataSourceRGAffinityGroupsGet: Error flatten data source rg affinity group get")
		return
	}

	// Set refreshed state
	resp.Diagnostics.Append(resp.State.Set(ctx, &state)...)
	if resp.Diagnostics.HasError() {
		tflog.Error(ctx, "Read dataSourceRGAffinityGroupsGet: Error set state")
		return
	}
	tflog.Info(ctx, "End read dataSourceRGAffinityGroupsGet")
}

func (d *dataSourceRGAffinityGroupsGet) Schema(ctx context.Context, _ datasource.SchemaRequest, resp *datasource.SchemaResponse) {
	resp.Schema = schema.Schema{
		Attributes: schemas.MakeSchemaDataSourceRGAffinityGroupsGet(),
		Blocks: map[string]schema.Block{
			"timeouts": timeouts.Block(ctx),
		},
	}
}

func (d *dataSourceRGAffinityGroupsGet) Metadata(_ context.Context, req datasource.MetadataRequest, resp *datasource.MetadataResponse) {
	resp.TypeName = req.ProviderTypeName + "_rg_affinity_groups_get"
}

// Configure adds the provider configured client to the data source.
func (d *dataSourceRGAffinityGroupsGet) Configure(ctx context.Context, req datasource.ConfigureRequest, resp *datasource.ConfigureResponse) {
	tflog.Info(ctx, "Get Configure dataSourceRGAffinityGroupsGet")
	d.client = client.DataSource(ctx, &req, resp)
	tflog.Info(ctx, "Getting Configure dataSourceRGAffinityGroupsGet successfully")
}
