_Resource_ функция **dynamix_lb_frontend** служит для управления фронтендом балансировщиком нагрузки (load balancer). Балансировщики нагрузки служат для равномерного распределения сетевой нагрузки между подключенными к ним сервисами. 

## Аргументы
_Resource_ функция **dynamix_lb_frontend** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | :---: | --- |
| lb_id | int | :heavy_check_mark: | ID балансировщика нагрузки |
| name | string | :heavy_check_mark: | Название фронтенда |
| backend_name | string | :heavy_check_mark: | Название бекенда балансировщика |


## Возвращаемые значения
В случае успешного выполнения _resource_ функция **dynamix_lb_frontend** возвращает в указанную при вызове переменную элемент, который состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| lb_id | int | ID балансировщика |
| backend_name | string | Имя бекенда, к которому подключен фронтенд |
| name | string | Имя фронтенда |
| bindings | []Struct{} [см. ниже](https://repository.basistech.ru/BASIS/terraform-provider-dynamix/src/branch/main/wiki/1.0.0/07.01.15-Resource_dynamix_lb_frontend.md#Описание-структуры-привязки-фронтенда) | Привязки фронтенда |

### Описание структуры привязки фронтенда
| Параметр | Тип | Описание |
| --- | --- | --- |
| address | string | Адрес, к которому привязан фронтенд |
| name | string | Имя привязки |
| port | int | Порт привязки |

## Импортирование ресурса
Так как ресурс lb_frontend является подресурсом lb, то для его импорта необходимо указать ID балансировщика, а так же само имя ресурса.  
Общая схема:
```terraform
terraform import dynamix_lb_frontend.<var> <lb_id>#<frontend-name>
```
Пример:
```
terraform import dynamix_lb_frontend.lb 777#testFrontend
```

## Ограничение на наименование ресурса
Ресурс не должен содержать в названии символ `#`

## Пример использования
Пример вызова _resource_ функции **dynamix_lb_frontend**:
```terraform
resource "dynamix_lb_frontend" "lb" {
  #id балансировщика нагрузок
  #обязательный параметр
  #тип - целое число
  lb_id = 668

  #имя бекенда для создания фронтенда
  #обязательный параметр
  #тип - строка
  backend_name = "testBackend"

  #имя фронтенда
  #обязательный параметр
  #тип - строка
  name = "testFrontend"

  timeouts {
    create = "5m"
    read   = "5m"
    update = "5m"
    delete = "5m"
  }
  
}
```

После успешного завершения такого вызова **dynamix_lb_frontend** в переменной `dynamix_lb_frontend.lb` будут сохранены возвращаемые значения.
